@@ -383,7 +383,7 @@ static void DrawGadget(struct GadgetInfo *gi, boolean pressed, boolean direct)
 	/* gadget text value */
 #if 1
 	DrawTextBuffer(gi->x + border_x, gi->y + border_y, gi->textarea.value,
-		       font_nr, gi->textarea.xsize, -1, gi->textarea.ysize,
+		       font_nr, gi->textarea.xsize, 0, -1, gi->textarea.ysize,
 		       BLIT_ON_BACKGROUND, FALSE, FALSE, FALSE);
 #else
 	DrawTextToTextArea(gi->x + border_x, gi->y + border_y,
